@@ -81,9 +81,12 @@
 	
 	foreach ($private_nets as $priv) {
 	    list ($private_net, $private_mask) = explode ("/", $priv);
-	    list ($net) = explode ("/", $ip);
+	    list ($net, $net_mask) = explode ("/", $ip);
 	    
-	    if (ip_same_network($net, $private_net, bitsmask_to_mask($private_mask)))
+	    if  (
+		(ip_same_network($net, $private_net, bitsmask_to_mask($private_mask))) ||	// base net is the same network as a private net
+		(ip_same_network($net, "0.0.0.0", bitsmask_to_mask($net_mask)))			// base net is 0.0.0.0
+		)
 		return true;
 	}
 	
