@@ -46,18 +46,20 @@
     function nad_view_host($host_id, $host, $ips, $ints) {
 	
 	$host_ips = array();
+	$ip_types = array();
 	foreach ($host["ips"] as $net=>$net_ips)
-	    foreach ($net_ips as $ip) {
-		$nets .= 
-		    tr(array(
-			linktext($net, $GLOBALS["REQUEST_URI"]."&nad_type=net&nad_id=".$net), 
-			$ip,
-			(!empty($ips[$ip]["dns"])?$ips[$ip]["dns"]:"&nbsp;"),
-			nad_ip_type($ips[$ip]["type"]))
-		    );
-		$host_ips[] = $ip;
-		$ip_types[$ip] = $ips[$ip]["type"];
-	    }
+	    foreach ($net_ips as $ip) 
+		if (ip2long($ip)!=-1) {
+		    $nets .= 
+			tr(array(
+			    linktext($net, $GLOBALS["REQUEST_URI"]."&nad_type=net&nad_id=".$net), 
+			    $ip,
+			    (!empty($ips[$ip]["dns"])?$ips[$ip]["dns"]:"&nbsp;"),
+			    nad_ip_type($ips[$ip]["type"]))
+			);
+		    $host_ips[] = $ip;
+		    $ip_types[$ip] = $ips[$ip]["type"];
+		}
 
 
 	reset($ints);
