@@ -107,23 +107,6 @@
 	);
 
 
-    $structures["traps_types"] = array(
-	"title"=>"SNMP Trap Events Types",
-	"object"=>"traps_types",
-	"show_id"=>1,
-	"action_type"=>1,
-	"profile"=>"ADMIN_SYSTEM",
-
-	"fields"=>array(
-	    "match_oid"=>array(	"name"=>"OID Match",		"type"=>"textbox",	"size"=>100),
-	    "interface"=>array(	"name"=>"Interface Field",	"type"=>"textbox",	"size"=>10),
-	    "username"=>array(	"name"=>"Username Field",	"type"=>"textbox",	"size"=>10),
-	    "state"=>array(	"name"=>"State Field",		"type"=>"textbox",	"size"=>10),
-	    "info"=>array(	"name"=>"Extra Info Field",	"type"=>"textbox",	"size"=>10),
-	    "type"=>array(	"name"=>"Event Type",		"type"=>"select",	"func"=>"select_event_types",	"view"=>"types_description", "size"=>30),
-	    NULL)
-	);
-
     $structures["syslog_types"] = array(
 	"title"=>"Syslog Events Types",
 	"object"=>"syslog_types",
@@ -349,6 +332,26 @@
 	    NULL)
 	);
 
+    $structures["trap_receivers"] = array(
+	"title"=>"SNMP Trap Receivers",
+	"object"=>"trap_receivers",
+	"show_id"=>1,
+	"action_type"=>1,
+	"hide_record_one"=>0,
+	"profile"=>"ADMIN_SYSTEM",
+	
+	"fields"=>array(
+	    "position"=>array(		"name"=>"Position",	"type"=>"textbox", "size"=>3),
+	    "description"=>array(	"name"=>"Description",	"type"=>"textbox","size"=>30),
+	    "interface_type"=>array(	"name"=>"Interface Type",	"type"=>"select",	"func"=>"select_interface_types", "view"=>"interface_type_description", "size"=>30),
+	    "match_oid"=>array(		"name"=>"OID Match",	"type"=>"textbox","size"=>50),
+	    "command"=>array(		"name"=>"Receiver Command (file)",	"type"=>"textbox","size"=>30),
+	    "parameters"=>array(	"name"=>"Parameters",	"type"=>"textbox","size"=>100),
+	    "backend"=>array(		"name"=>"Backend",	"type"=>"select",	"func"=>"select_backends",	"size"=>30, "view"=>"backend_description"),
+	    "stop_if_matches"=>array(	"name"=>"Stop if Matches",		"type"=>"checkbox"),
+	    NULL)
+	);
+
     $structures["pollers_backend"] = array(
 	"title"=>"Pollers Backends",
 	"object"=>"pollers_backend",
@@ -462,6 +465,7 @@
 	"show_id"=>0,
 	"action_type"=>1,
 	"filter_by_user"=>"user_id",
+	"filter_field"=>"user_id",
 	
 	"fields"=>array(
 	    "trigger_id"=>array(	"name"=>"Trigger",	"type"=>"select",	"func"=>"select_triggers",	"size"=>30, "view"=>"trigger_description"),
