@@ -1,11 +1,15 @@
 <?
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
     if (is_array($text_to_show)) {
 	$html_current_x += $html_separation_x;
 
         $bgcolor = "rgb(150,150,150)";
         $fgcolor = "white";
 
-	$text_to_show = join("<br>",$text_to_show);
+	$text_to_show = join(br(),$text_to_show);
 
         unset($events);
 
