@@ -123,20 +123,6 @@
 	var $jffnms_insert = array("severity"=>"New Severity",bgcolor=>"000000",fgcolor=>"FFFFFF"); 
     }
 
-    class jffnms_traps_types extends internal_base_standard 	{ 
-	var $jffnms_class = "traps_types";  
-	var $jffnms_insert = array("match_oid"=>"New Trap OID"); 
-
-        function get_all($ids = NULL)	{ 
-	    return get_db_list(	
-		array($this->jffnms_class,"types"),	$ids, 
-		array($this->jffnms_class.".*","types_description"=>"types.description") ,	
-		array(array($this->jffnms_class.".type","=","types.id"),array($this->jffnms_class.".id",">",1)),
-		array(array($this->jffnms_class.".id","desc"))
-		); 
-	}
-    }
-
     class jffnms_journal extends internal_base_standard 	{ 
 	var $jffnms_class = "journal";  
 	var $jffnms_insert = array("subject"=>"New Journal"); 
@@ -298,6 +284,32 @@
 	var $jffnms_order_type = "asc";
     }
 
+    class jffnms_trap_receivers	extends internal_base_standard 	{ 
+	var $jffnms_class = "trap_receivers";  
+	var $jffnms_insert = array("description"=>"a New Trap Receiver", "match_oid"=>"Trap OID", "position"=>"10", "command"=>"none");
+	var $jffnms_filter_record = 0;
+
+        function get_all($ids = NULL)	{ 
+	    return get_db_list(	
+		array($this->jffnms_class,"interface_types","pollers_backend"),	$ids, 
+		array(
+		    $this->jffnms_class.".*",
+		    "interface_type_description"=>"interface_types.description", 
+		    "backend_description"=>"pollers_backend.description"
+		    ) ,	
+		array(
+		    array($this->jffnms_class.".interface_type","=","interface_types.id"),
+		    array($this->jffnms_class.".backend","=","pollers_backend.id")
+		    ),
+		array(
+		    array($this->jffnms_class.".position","asc"),
+		    array($this->jffnms_class.".description","asc"),
+		    array($this->jffnms_class.".id","desc")
+		    )
+		); 
+	}
+    }
+
     class jffnms_pollers_groups extends internal_base_standard 	{ 
 	var $jffnms_class = "pollers_groups";  
 	var $jffnms_insert = array("description"=>"New Poller Group"); 
