@@ -304,7 +304,7 @@
 	if ($process_name_len > 1)			//if name is rigth
 	if (get_config_option ("os_type")=="unix") {	//if we are on a Unix OS
 	
-	    exec("ps -eo args",$ps_list); //call 'ps'
+	    exec("ps axo args",$ps_list); //call 'ps'
 
 	    if (count($ps_list) > 0)
 		foreach ($ps_list as $process) {
