@@ -260,26 +260,26 @@ function select_pollers_groups ($name,$poller_group_id,$type = 0) {
 $trigger_fields = array(
     "event"=>array(
 	"any"=>			array("name"=>"Any"),
-    	"date"=>		array("name"=>"Hour",		"function"=>"select_hours",		"params"=>NULL),
+    	"date"=>		array("name"=>"Hour",		"function"=>"select_hours",		"params"=>array()),
 	"host_id"=>		array("name"=>"Host",		"function"=>"select_hosts",		"params"=>array(3)),
-	"zone_id"=>		array("name"=>"Zone",		"function"=>"select_zones",		"params"=>NULL),
+	"zone_id"=>		array("name"=>"Zone",		"function"=>"select_zones",		"params"=>array()),
 	"type_id"=>		array("name"=>"Type",		"function"=>"select_event_types",	"params"=>array(3)),
 	"text"=>		array("name"=>"Event Text",	"function"=>"textbox",			"params"=>array(30)),
 	"interface_id"=>	array("name"=>"Interface",	"function"=>"select_interfaces",	"params"=>array(6)),
-	"map"=>			array("name"=>"Interface Maps", "function"=>"select_maps",		"params"=>NULL),
+	"map"=>			array("name"=>"Interface Maps", "function"=>"select_maps",		"params"=>array()),
 	"interface_client_id"=>	array("name"=>"Client", 	"function"=>"select_clients",		"params"=>array(3)),
 	"none"=>		array("name"=>"None")
     ),
     "alarm"=>array(
 	"any"=>			array("name"=>"Any"),
-    	"date"=>		array("name"=>"Hour",		"function"=>"select_hours",		"params"=>NULL),
+    	"date"=>		array("name"=>"Hour",		"function"=>"select_hours",		"params"=>array()),
 	"type"=>		array("name"=>"Type",		"function"=>"select_event_types_alarms","params"=>array(3)),
-	"duration"=>    	array("name"=>"Duration",	"function"=>"select_alarm_duration",    "params"=>NULL),
-	"active"=>		array("name"=>"State",		"function"=>"select_alarm_states",	"params"=>NULL),
+	"duration"=>    	array("name"=>"Duration",	"function"=>"select_alarm_duration",    "params"=>array()),
+	"active"=>		array("name"=>"State",		"function"=>"select_alarm_states",	"params"=>array()),
 	"interface_host"=>	array("name"=>"Host",		"function"=>"select_hosts",		"params"=>array(3)),
 	"interface_type"=>	array("name"=>"Interface Type",	"function"=>"select_interface_types",	"params"=>array(3)),
 	"interface"=>		array("name"=>"Interface",	"function"=>"select_interfaces_host",	"params"=>array(6)),
-	"map"=>			array("name"=>"Interface Maps", "function"=>"select_maps",		"params"=>NULL),
+	"map"=>			array("name"=>"Interface Maps", "function"=>"select_maps",		"params"=>array()),
 	"interface_client_id"=>	array("name"=>"Client", 	"function"=>"select_clients",		"params"=>array(3)),
 	"interface_interface"=> array("name"=>"Interface Name", "function"=>"textbox",                  "params"=>array(30)), 
 	"none"=>		array("name"=>"None")
@@ -290,7 +290,7 @@ $trigger_fields = array(
 	global $trigger_fields;
 	
 	foreach ($trigger_fields[$type] as $key=>$aux)
-	    $temp[$key]=$aux[name];
+	    $temp[$key]=$aux["name"];
 	
 	if ($text==0)
 	    return select_custom($name,$temp,$value);
@@ -301,10 +301,12 @@ $trigger_fields = array(
 
     function select_trigger_fields_value($name,$value,$type,$field) {
 	global $trigger_fields;
-	if ((!$field) || ($field=="any") || ($field=="none")) return;
+    
+	if ((!$field) || ($field=="any") || ($field=="none")) 
+	    return;
 	else 
 	    return call_user_func_array($trigger_fields[$type][$field]["function"],
-		array_merge(array($name,$value),$trigger_fields[$type][$field][params]));
+		array_merge(array($name, $value), $trigger_fields[$type][$field]["params"]));
     }
 
     function select_action_parameters($name,$value,$field_struct,$text = 0) {
